#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infinite-list
version:              0.1.3
visibility:           public
id:                   infinite-list-0.1.3-8RHlsNqVLbgJXIdzfsU5zp
key:                  infinite-list-0.1.3-8RHlsNqVLbgJXIdzfsU5zp
license:              BSD-3-Clause
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/infinite-list
synopsis:             Infinite lists
description:
    Modern lightweight library for infinite lists with fusion:

    * API similar to "Data.List".
    * No dependencies other than `base`.
    * Top performance, driven by fusion.
    * Avoid dangerous instances like `Foldable`.
    * Use `NonEmpty` where applicable.
    * Use `Word` for indices.
    * Be lazy, but not too lazy.

    @
    {\-# LANGUAGE PostfixOperators #-\}
    import Data.List.Infinite (Infinite(..), (...), (....))
    import qualified Data.List.Infinite as Inf
    @

category:             Data
abi:                  aa34fd505497d15b5e1a466964d9aa33
exposed:              True
exposed-modules:      Data.List.Infinite
hidden-modules:
    Data.List.Infinite.Internal Data.List.Infinite.Set
    Data.List.Infinite.Zip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infinite-list
hs-libraries:         HSinfinite-list-0.1.3-8RHlsNqVLbgJXIdzfsU5zp
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-infinite-list/html/infinite-list.haddock

haddock-html:         /usr/share/doc/haskell-infinite-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

